==> python-pykmip_0.7.0.orig.tar.xz: python-pykmip-0.7.0/kmip/core/messages/payloads/__init__.py <==
# Copyright (c) 2014 The Johns Hopkins University/Applied Physics Laboratory
# All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

from kmip.core.messages.payloads.activate import (
    ActivateRequestPayload,
    ActivateResponsePayload
)
from kmip.core.messages.payloads.create import (
    CreateRequestPayload,
    CreateResponsePayload
)
from kmip.core.messages.payloads.create_key_pair import (
    CreateKeyPairRequestPayload,
    CreateKeyPairResponsePayload
)
from kmip.core.messages.payloads.decrypt import (
    DecryptRequestPayload,
    DecryptResponsePayload
)
from kmip.core.messages.payloads.derive_key import (
    DeriveKeyRequestPayload,
    DeriveKeyResponsePayload
)
from kmip.core.messages.payloads.destroy import (
    DestroyRequestPayload,
    DestroyResponsePayload
)
from kmip.core.messages.payloads.discover_versions import (
    DiscoverVersionsRequestPayload,
    DiscoverVersionsResponsePayload
)
from kmip.core.messages.payloads.encrypt import (
    EncryptRequestPayload,
    EncryptResponsePayload
)
from kmip.core.messages.payloads.get import (
    GetRequestPayload,
    GetResponsePayload
)
from kmip.core.messages.payloads.get_attribute_list import (
    GetAttributeListRequestPayload,
    GetAttributeListResponsePayload
)
from kmip.core.messages.payloads.get_attributes import (
    GetAttributesRequestPayload,
    GetAttributesResponsePayload
)
from kmip.core.messages.payloads.locate import (
    LocateRequestPayload,
    LocateResponsePayload
)
from kmip.core.messages.payloads.mac import (
    MACRequestPayload,
    MACResponsePayload
)
from kmip.core.messages.payloads.query import (
    QueryRequestPayload,
    QueryResponsePayload
)
from kmip.core.messages.payloads.register import (
    RegisterRequestPayload,
    RegisterResponsePayload
)
from kmip.core.messages.payloads.rekey_key_pair import (
    RekeyKeyPairRequestPayload,
    RekeyKeyPairResponsePayload
)
from kmip.core.messages.payloads.revoke import (
    RevokeRequestPayload,
    RevokeResponsePayload
)
from kmip.core.messages.payloads.sign import (
    SignRequestPayload,
    SignResponsePayload
)
from kmip.core.messages.payloads.signature_verify import (
    SignatureVerifyRequestPayload,
    SignatureVerifyResponsePayload
)


__all__ = [
    "ActivateRequestPayload",
    "ActivateResponsePayload",
    "CreateRequestPayload",
    "CreateResponsePayload",
    "CreateKeyPairRequestPayload",
    "CreateKeyPairResponsePayload",
    "DecryptRequestPayload",
    "DecryptResponsePayload",
    "DeriveKeyRequestPayload",
    "DeriveKeyResponsePayload",
    "DestroyRequestPayload",
    "DestroyResponsePayload",
    "DiscoverVersionsRequestPayload",
    "DiscoverVersionsResponsePayload",
    "EncryptRequestPayload",
    "EncryptResponsePayload",
    "GetRequestPayload",
    "GetResponsePayload",
    "GetAttributeListRequestPayload",
    "GetAttributeListResponsePayload",
    "GetAttributesRequestPayload",
    "GetAttributesResponsePayload",
    "LocateRequestPayload",
    "LocateResponsePayload",
    "MACRequestPayload",
    "MACResponsePayload",
    "QueryRequestPayload",
    "QueryResponsePayload",
    "RegisterRequestPayload",
    "RegisterResponsePayload",
    "RekeyKeyPairRequestPayload",
    "RekeyKeyPairResponsePayload",
    "RevokeRequestPayload",
    "RevokeResponsePayload",
    "SignRequestPayload",
    "SignResponsePayload",
    "SignatureVerifyRequestPayload",
    "SignatureVerifyResponsePayload"
]

==> python-pykmip_0.9.1.orig.tar.xz: python-pykmip-0.9.1/kmip/core/messages/payloads/__init__.py <==
# Copyright (c) 2014 The Johns Hopkins University/Applied Physics Laboratory
# All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

from kmip.core.messages.payloads.activate import (
    ActivateRequestPayload,
    ActivateResponsePayload
)
from kmip.core.messages.payloads.archive import (
    ArchiveRequestPayload,
    ArchiveResponsePayload
)
from kmip.core.messages.payloads.cancel import (
    CancelRequestPayload,
    CancelResponsePayload
)
from kmip.core.messages.payloads.check import (
    CheckRequestPayload,
    CheckResponsePayload
)
from kmip.core.messages.payloads.create import (
    CreateRequestPayload,
    CreateResponsePayload
)
from kmip.core.messages.payloads.create_key_pair import (
    CreateKeyPairRequestPayload,
    CreateKeyPairResponsePayload
)
from kmip.core.messages.payloads.decrypt import (
    DecryptRequestPayload,
    DecryptResponsePayload
)
from kmip.core.messages.payloads.derive_key import (
    DeriveKeyRequestPayload,
    DeriveKeyResponsePayload
)
from kmip.core.messages.payloads.destroy import (
    DestroyRequestPayload,
    DestroyResponsePayload
)
from kmip.core.messages.payloads.discover_versions import (
    DiscoverVersionsRequestPayload,
    DiscoverVersionsResponsePayload
)
from kmip.core.messages.payloads.encrypt import (
    EncryptRequestPayload,
    EncryptResponsePayload
)
from kmip.core.messages.payloads.get import (
    GetRequestPayload,
    GetResponsePayload
)
from kmip.core.messages.payloads.get_attribute_list import (
    GetAttributeListRequestPayload,
    GetAttributeListResponsePayload
)
from kmip.core.messages.payloads.get_attributes import (
    GetAttributesRequestPayload,
    GetAttributesResponsePayload
)
from kmip.core.messages.payloads.get_usage_allocation import (
    GetUsageAllocationRequestPayload,
    GetUsageAllocationResponsePayload
)
from kmip.core.messages.payloads.locate import (
    LocateRequestPayload,
    LocateResponsePayload
)
from kmip.core.messages.payloads.mac import (
    MACRequestPayload,
    MACResponsePayload
)
from kmip.core.messages.payloads.obtain_lease import (
    ObtainLeaseRequestPayload,
    ObtainLeaseResponsePayload
)
from kmip.core.messages.payloads.poll import (
    PollRequestPayload
)
from kmip.core.messages.payloads.query import (
    QueryRequestPayload,
    QueryResponsePayload
)
from kmip.core.messages.payloads.recover import (
    RecoverRequestPayload,
    RecoverResponsePayload
)
from kmip.core.messages.payloads.register import (
    RegisterRequestPayload,
    RegisterResponsePayload
)
from kmip.core.messages.payloads.rekey_key_pair import (
    RekeyKeyPairRequestPayload,
    RekeyKeyPairResponsePayload
)
from kmip.core.messages.payloads.rekey import (
    RekeyRequestPayload,
    RekeyResponsePayload
)
from kmip.core.messages.payloads.revoke import (
    RevokeRequestPayload,
    RevokeResponsePayload
)
from kmip.core.messages.payloads.sign import (
    SignRequestPayload,
    SignResponsePayload
)
from kmip.core.messages.payloads.signature_verify import (
    SignatureVerifyRequestPayload,
    SignatureVerifyResponsePayload
)


__all__ = [
    "ActivateRequestPayload",
    "ActivateResponsePayload",
    "ArchiveRequestPayload",
    "ArchiveResponsePayload",
    "CancelRequestPayload",
    "CancelResponsePayload",
    "CheckRequestPayload",
    "CheckResponsePayload",
    "CreateRequestPayload",
    "CreateResponsePayload",
    "CreateKeyPairRequestPayload",
    "CreateKeyPairResponsePayload",
    "DecryptRequestPayload",
    "DecryptResponsePayload",
    "DeriveKeyRequestPayload",
    "DeriveKeyResponsePayload",
    "DestroyRequestPayload",
    "DestroyResponsePayload",
    "DiscoverVersionsRequestPayload",
    "DiscoverVersionsResponsePayload",
    "EncryptRequestPayload",
    "EncryptResponsePayload",
    "GetRequestPayload",
    "GetResponsePayload",
    "GetAttributeListRequestPayload",
    "GetAttributeListResponsePayload",
    "GetAttributesRequestPayload",
    "GetAttributesResponsePayload",
    "GetUsageAllocationRequestPayload",
    "GetUsageAllocationResponsePayload",
    "LocateRequestPayload",
    "LocateResponsePayload",
    "MACRequestPayload",
    "MACResponsePayload",
    "ObtainLeaseRequestPayload",
    "ObtainLeaseResponsePayload",
    "PollRequestPayload",
    "QueryRequestPayload",
    "QueryResponsePayload",
    "RecoverRequestPayload",
    "RecoverResponsePayload",
    "RegisterRequestPayload",
    "RegisterResponsePayload",
    "RekeyKeyPairRequestPayload",
    "RekeyKeyPairResponsePayload",
    "RekeyRequestPayload",
    "RekeyResponsePayload",
    "RevokeRequestPayload",
    "RevokeResponsePayload",
    "SignRequestPayload",
    "SignResponsePayload",
    "SignatureVerifyRequestPayload",
    "SignatureVerifyResponsePayload"
]
